<!--面包屑导航-->
<template>
  <div class="home-main-page">
    <!-- 顶部 -->
    <div class="top-container">
      <div class="item">
        <div class="value">135,278,743.55</div>
        <div class="label">总的土地面积(亩)</div>
      </div>
      <div class="item">
        <div class="value">1,194,337.69</div>
        <div class="label">今年新增面积(亩)</div>
      </div>
      <div class="item">
        <div class="value">1,194,337.69</div>
        <div class="label">总账面价值(万元)</div>
      </div>
      <div class="item">
        <div class="value">1,194,337.69</div>
        <div class="label">总的未确权面积(亩)</div>
      </div>
    </div>
    <!-- 中间 -->
    <div class="center-container">
      <div class="center-left">
        <div class="item">
          <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="土地属性" />
          <div class="content">
            <ScaleDrawing :leftData="leftData" :rightData="rightData" />
          </div>
        </div>
        <div class="item">
          <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="土地类型" />
          <div class="content">
            <ScaleDrawing :leftData="leftData" :rightData="rightData" />
          </div>
        </div>
      </div>
      <div class="center-center">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="土地状态" />
        <div id="ownership-chart"></div>
      </div>
      <div class="center-right">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="土地来源" />
        <div id="stats-chart"></div>

      </div>
    </div>
    <!-- 底部 -->
    <div class="bottom-container">
      <div class="bottom-left">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="各业态土地面积" />
        <div id="source-chart"></div>
      </div>
      <div class="bottom-center">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="资产盘活" />
        <div id="type-chart"></div>
      </div>
      <div class="bottom-right">
        <PublicTitle :iconUrl="require('@/assets/img/publicTitle/icon-土地.png')" title="各业态土地面积" />
        <div id="interest-chart"></div>
      </div>
    </div>
  </div>
</template>

<script>

import * as echarts from 'echarts'
import utils from '@/utils.js'
import PublicTitle from '@/components/PublicTitle/index'
import ScaleDrawing from '@/components/ScaleDrawing/index'
import api from '@/api/assetsOperating/assetsOperating.js'
export default {
  name: 'HomePage', // 首页
  components: {
    PublicTitle,
    ScaleDrawing
    // OperatingAssets,
    // LandAssets
  },
  data() {
    return {
      colorList: ['#55edb0', '#00d4ff', '#c679e5', '#198cff'],
      dataList: [
        {
          name: '商业用地',
          value: '12%',
        },
        {
          name: '住宅用地',
          value: '6%',
        },
      ],
      topStatistics: {},//顶部统计
      ownershipData: [],//权属
      statsData: [],//属性
      commercialData: [],//业态
      sourceData: [],//来源
      statusData: [],//状态
      typeData: [],//类型
      leftData: {
        name: '政府资产',
        value: 44639371,
        unit: '亩'
      },
      rightData: {
        name: '企业资产',
        value: 67639371,
        unit: '亩'
      }
    }
  },
  watch: {},
  created() {
    this.belongStatistics()
    this.natureStatistics()
    this.sourceStatistics()
    this.statusStatistics()
    this.typeStatistics()
  },
  mounted() {

  },
  methods: {
    //字典翻译
    getDictName(code, value) {
      return utils.getDictName(code, value)
    },
    //权属分布
    belongStatistics() {
      api.belongStatistics({}, res => {
        if (res.state) {
          this.ownershipData = res.value
        }
        this.$nextTick(() => {
          this.initOwnershipChat()
        })
      })
    },
    //资产属性分布
    natureStatistics() {
      api.natureStatistics({}, res => {
        if (res.state) {
          this.statsData = res.value
        }
        this.$nextTick(() => {
          this.initStatsChat()
        })
      })
    },
    //资产来源情况
    sourceStatistics() {
      api.sourceStatistics({}, res => {
        if (res.state) {
          this.sourceData = res.value
        }
        this.$nextTick(() => {
          this.initChat()
        })
      })
    },
    //资产状态情况
    statusStatistics() {
      api.statusStatistics({}, res => {
        if (res.state) {
          this.statusData = res.value
        }
        this.$nextTick(() => {
          this.initSourceChat()
        })
      })
    },
    //资产类型分布
    typeStatistics() {
      api.typeStatistics({}, res => {
        if (res.state) {
          this.typeData = res.value
        }
        this.$nextTick(() => {
          this.initTypeChat()
        })
      })
    },
    initOwnershipChat() {
      let echartsData = [
        {
          name: '闲置',
          value: '10',
          itemStyle: {
            color: '#198CFF',
          },
        }, {
          name: '自用',
          value: '10',
          itemStyle: {
            color: '#00D4FF',
          },
        }, {
          name: '出租',
          value: '10',
          itemStyle: {
            color: '#55EDB0',
          },
        }, {
          name: '借用',
          value: '10',
          itemStyle: {
            color: '#FFDB2A',
          },
        }, {
          name: '存量',
          value: '10',
          itemStyle: {
            color: '#FDB942',
          },
        }, {
          name: '被占用',
          value: '10',
          itemStyle: {
            color: '#FF8F57',
          },
        }, {
          name: '新增',
          value: '10',
          itemStyle: {
            color: '#C679E5',
          },
        }, {
          name: '其他',
          value: '10',
          itemStyle: {
            color: '#EA38C0',
          },
        },
      ]
      // this.ownershipData.forEach((e, index) => {
      //   echartsData.push({
      //     name: this.getDictName('xmgs', e.assetBelong),
      //     value: e.count,
      //     itemStyle: {
      //       color: this.colorList[index],
      //     },
      //   })
      // })
      let chartDom = echarts.init(document.getElementById('ownership-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          orient: 'vertical',
          top: 'middle',
          right: 110,
          selectedMode: false
        },
        series: [

          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.value +
                    '}' +
                    '{unit|亩}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    initStatsChat() {
      let echartsData = [
        {
          name: '自建',
          value: '10',
          itemStyle: {
            color: '#198CFF',
          },
        }, {
          name: '购买',
          value: '10',
          itemStyle: {
            color: '#00D4FF',
          },
        }, {
          name: '划拔',
          value: '10',
          itemStyle: {
            color: '#FFDB2A ',
          },
        }, {
          name: '置换',
          value: '10',
          itemStyle: {
            color: '#FDB942',
          },
        }, {
          name: '出让',
          value: '10',
          itemStyle: {
            color: '#FF8F57',
          },
        }
      ]
      // this.statsData.forEach((e, index) => {

      //   echartsData.push({
      //     name: this.getDictName('xmsx', e.assetNature),
      //     value: e.count,
      //     itemStyle: {
      //       color: this.colorList[2 + index],
      //     },
      //   })
      // })
      let chartDom = echarts.init(document.getElementById('stats-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          orient: 'vertical',
          top: 'middle',
          right: 110,
          selectedMode: false
        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  return [
                    '{num|' +
                    params.value +
                    '}' +
                    '{unit|个}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          // 外圈背景
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },

        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          console.log(1);
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })

      }
    },
    initTypeChat() {
      let echartsData = [
        {
          name: '已盘活',
          value: 5,
          itemStyle: {
            color: '#FFAE5E',
          },
        }, {
          name: '待盘活',
          value: 15,
          itemStyle: {
            color: '#55EDB0 ',
          },
        }
      ]
      // this.typeData.forEach((e, index) => {
      //   echartsData.push({
      //     name: this.getDictName('zclx', e.assetType),
      //     value: e.count,
      //     itemStyle: {
      //       color: this.colorList[index],
      //     },
      //   })
      // })
      let chartDom = echarts.init(document.getElementById('type-chart'))
      let option = {
        tooltip: {
          trigger: 'item',
        },
        legend: {
          orient: 'vertical',
          top: 'middle',
          right: 110,
          selectedMode: false
        },
        series: [
          {
            name: '面积',
            type: 'pie',
            radius: ['55%', '67%'],
            center: ['35%', '48.4%'],
            avoidLabelOverlap: false,
            itemStyle: {
              borderColor: '#fff',
              borderWidth: 2,
            },
            label: {
              show: false,
              position: 'center',
            },

            emphasis: {
              label: {
                show: true,
                fontSize: 30,
                formatter: function (params) {
                  console.log(params);
                  return [
                    '{num|' +
                    params.percent  +
                    '}' +
                    '{unit|%}',
                    '{label|' + params.name + '}',
                  ].join('\n')
                },
                rich: {
                  num: {
                    fontSize: 30,
                    color: '#000',
                    lineHeight: 30,
                    fontWeight: 700,
                  },
                  unit: {
                    fontSize: 14,
                    color: '#111',
                    lineHeight: 30,
                    padding: [0, 5],
                  },
                  label: {
                    fontSize: 20,
                    lineHeight: 30,
                    color: '#444',
                  },
                },
              },
            },
            labelLine: {
              show: false,
            },
            data: echartsData,
          },
          // 外圈背景
          {
            type: 'pie',
            radius: ['50%', '50%'],
            center: ['35%', '48.4%'],
            hoverAnimation: false,
            clockWise: false,
            cursor: 'default',
            itemStyle: {
              normal: {
                borderWidth: 2,
                borderColor: '#eaeaea',
              },
            },
            tooltip: {
              show: false,
            },
            label: {
              show: false,
            },
            data: [100],
          },
          {
            type: 'gauge',
            radius: '98%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 200, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 15,
              lineStyle: {
                color: '#eaeaea',
                width: 1,
              },
            },
            axisLabel: {
              show: false,
            },
          },
          {
            type: 'gauge',
            radius: '83.5%',
            center: ['35%', '48.4%'],
            clockwise: true,
            startAngle: '100',
            endAngle: '-269.9999',
            splitNumber: 140, //线的条数
            pointer: {
              show: false,
            },
            axisLine: {
              show: false,
            },
            axisTick: {
              show: false,
            },
            tooltip: {
              show: false,
            },
            splitLine: {
              show: true,
              length: 1,
              lineStyle: {
                color: '#eaeaea',
                width: 2,
              },
            },
            axisLabel: {
              show: false,
            },
          },


        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
      handleChartLoop(option, chartDom);
      // 饼图自动轮播
      function handleChartLoop(option, myChart) {
        if (!myChart) {
          return
        }
        let currentIndex = 0 // 当前高亮图形在饼图数据中的下标
        highlightPie()
        // 取消所有高亮并高亮当前图形
        function highlightPie() {
          // 遍历饼图数据，取消所有图形的高亮效果
          for (var idx in option.series[0].data) {
            myChart.dispatchAction({
              type: 'downplay',
              seriesIndex: 0,
              dataIndex: idx
            })
          }
          // 高亮当前图形
          myChart.dispatchAction({
            type: 'highlight',
            seriesIndex: 0,
            dataIndex: currentIndex
          })
        }
        // // 用户鼠标悬浮到某一图形时，停止自动切换并高亮鼠标悬浮的图形
        myChart.on('mouseover', (params) => {
          if (params.componentType == 'graphic') {
            return
          }
          currentIndex = params.dataIndex
          highlightPie()
        })
      }
    },
    initChat() {
      let xData = ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
      let bookData = [22, 44, 22, 11, 20, 44, 23, 56, 77, 44, 42, 31]

      let chartDom = echarts.init(
        document.getElementById('interest-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis', // 设置触发类型为坐标轴轴线触发
        },
        grid: {
          top: '21%',
          bottom: '5%',
          right: '5%',
        },
        xAxis: {
          type: 'category',
          data: xData,
          boundaryGap: false,
          axisTick: {
            show: false,
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
        },
        yAxis: {
          type: 'value',
          name: '土地转让面积 (亩)',
          axisLine: {
            show: true,
            lineStyle: {
              color: '#A1A9B2', // 浅灰色
            },
          },
          splitLine: {
            show: false,
          },
        },
        series: [
          {
            type: 'line',
            data: bookData,
            type: 'line',
            smooth: true,
            // symbol: 'none', // 取消小圆点的显示
            showSymbol: false, // 取消小圆点的显示
            lineStyle: {
              color: '#198CFF', // 设置线条的颜色为红色
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },
    initSourceChat() {
      let xData = ['殡并', '城镇村道路', '工业', '公路', '公用设施', '公园与绿地', '交通服务场站', '教育', '零售商业', '商务金融', '其他商服', '社会福利',]
      let bookData = [23, 33, 41, 15, 32, 45, 32, 13, 54, 76]
      // this.statusData.forEach(e => {
      //   xData.push(this.getDictName('zczt', e.assetStatus))
      //   bookData.push(e.bookValue)
      //   structureData.push(e.structure_area_)
      // })
      let chartDom = echarts.init(
        document.getElementById('source-chart')
      )
      let option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            // 坐标轴指示器，坐标轴触发有效
            type: 'shadow', // 默认为直线，可选为：'line' | 'shadow'
          },
        },
        grid: {
          left: '3%',
          right: '4%',
          bottom: '3%',
          containLabel: true,
        },
        xAxis: [
          {
            type: 'category',
            data: xData,
            axisTick: {
              show: false,
            },
            axisLabel: {
              interval: 0, //坐标刻度之间的显示间隔，默认就可以了（默认是不重叠）
              rotate: 38   //调整数值改变倾斜的幅度（范围-90到90）
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          },
        ],
        yAxis: [
          {
            type: 'value',
            name: '单位：亩',
            axisLabel: {
              formatter: '{value}',

            },
            splitLine: {
              show: false,
            },
            axisLine: {
              show: true,
              lineStyle: {
                color: '#A1A9B2', // 浅灰色
              },
            },
          }
        ],
        series: [
          {
            type: 'bar',
            data: bookData,
            barWidth: '15',
            yAxisIndex: 0,
            itemStyle: {
              color: {
                type: 'linear',
                x: 0,
                y: 0,
                x2: 0,
                y2: 1,
                colorStops: [
                  {
                    offset: 0,
                    color: '#55EDB0', // 渐变起始颜色（绿色）
                  },
                ],
              },
              borderRadius: [3, 3, 0, 0], // 设置圆角大小
            },
          },
        ],
      }
      chartDom.setOption(option)
      window.addEventListener('resize', () => {
        chartDom.resize()
      })
    },

  },
  beforeDestroy() { },
}
</script>

<style lang="scss" scoped>
.home-main-page {
  box-sizing: border-box;
  padding: 15px 0;
  width: 100%;
  height: 100%;
  padding: 16px 24px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  align-items: center;

  .top-container {
    width: 100%;
    height: 16%;
    display: flex;
    background: linear-gradient(180deg, #CCE5FF 0%, #EEF8FF 100%);
    border-radius: 16px 16px 16px 16px;
    opacity: 1;
    border: 1px solid;
    border-image: linear-gradient(180deg, rgba(238.00000101327896, 248.0000004172325, 255, 1), rgba(255, 255, 255, 1)) 1 1;
    padding: 24px 0;
    box-sizing: border-box;

    .item {
      flex: 1;
      display: flex;
      flex-direction: column;
      justify-content: center;
      align-items: center;
      border-right: 1px solid #fff;

      .value {
        font-size: 26px;
        font-weight: 700;
        color: #0f2a4d;
      }

      .label {
        font-size: 16px;
        font-weight: 700;
        color: #0f2a4d;
      }

      &:nth-child(4) {
        border-right: none;
      }
    }
  }

  .center-container {
    width: 100%;
    height: 40%;
    display: flex;
    justify-content: space-between;

    .center-left {
      width: calc(40% - 32px);
      height: 100%;
      display: flex;
      flex-direction: column;
      justify-content: space-between;

      .item {
        width: 100%;
        padding: 16px;
        box-sizing: border-box;
        height: calc(50% - 8px);
        background: #FFFFFF;
        box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
        border-radius: 16px 16px 16px 16px;
        opacity: 1;

        .content {
          width: 100%;
          height: calc(100% - 30px);
          padding: 0 40px;
          box-sizing: border-box;
          display: flex;
          flex-direction: column;
          justify-content: space-evenly;
        }
      }
    }

    .center-center {
      width: 30%;
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #ownership-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

    .center-right {
      width: 30%;
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #stats-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }
  }

  .bottom-container {
    width: 100%;
    height: 40%;
    display: flex;
    justify-content: space-between;

    .bottom-left {
      width: calc(40% - 32px);
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #source-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

    .bottom-center {
      width: 30%;
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #type-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

    .bottom-right {
      width: 30%;
      height: 100%;
      padding: 16px;
      box-sizing: border-box;
      background: #FFFFFF;
      box-shadow: 4px 4px 10px 0px rgba(53, 152, 220, 0.1);
      border-radius: 16px 16px 16px 16px;
      opacity: 1;

      #interest-chart {
        width: 100%;
        height: calc(100% - 30px);
      }
    }

  }
}
</style>
